@@ -595,15 +595,12 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		break;
 	case GDK_Page_Up:
 	case GDK_KP_Page_Up:
-		gtk_adjustment_set_value(gs->vadj, gs->vadj->value - gs->vadj->page_increment);
+		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 		break;
 	case GDK_Page_Down:
 	case GDK_KP_Page_Down:
-		val = gs->vadj->value + gs->vadj->page_increment;
-		if (val > gs->vadj->upper - gs->vadj->page_size)
-			val = gs->vadj->upper - gs->vadj->page_size;
-		gtk_adjustment_set_value(gs->vadj, val);
-			break;
+		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
+		break;
 	case GDK_plus:
 		g_signal_emit_by_name(G_OBJECT (control->priv->zoomable),
 							  "zoom_in");
@@ -722,8 +719,6 @@ static void
 ggv_control_create_ui (GgvControl *control)
 {
 	GgvControlClass *klass;
-	GdkPixbuf *pixbuf, *pixbuf_small;
-	gchar *pixbuf_xml;
 	int i;
 
 	g_return_if_fail (control != NULL);
@@ -739,29 +734,6 @@ ggv_control_create_ui (GgvControl *control)
 	bonobo_ui_component_freeze(control->priv->popup_uic, NULL);
 	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-postscript-view-ui.xml", "GGV", NULL);
 	bonobo_ui_util_set_ui(control->priv->popup_uic, DATADIR, "ggv-control-ui.xml", "GGV", NULL);
-	
-	pixbuf = gdk_pixbuf_new_from_file(GNOMEICONDIR "/ggv/fitwidth.png", NULL);
-	if(pixbuf != NULL) {
-		pixbuf_xml = bonobo_ui_util_pixbuf_to_xml(pixbuf);
-		bonobo_ui_component_set_prop(control->priv->uic,
-									 "/Toolbar/Viewer Items Placeholder/Zoom Items Placeholder/ZoomToFitWidth",
-									 "pixname", pixbuf_xml,
-									 NULL);
-		g_free(pixbuf_xml);
-		pixbuf_small = gdk_pixbuf_scale_simple(pixbuf, 18, 18, GDK_INTERP_TILES);
-		pixbuf_xml = bonobo_ui_util_pixbuf_to_xml(pixbuf_small);
-		bonobo_ui_component_set_prop(control->priv->uic,
-									 "/menu/View/Zoom Items Placeholder/Zoom/ZoomToFitWidth",
-									 "pixname", pixbuf_xml,
-									 NULL);
-		bonobo_ui_component_set_prop(control->priv->popup_uic,
-									 "/popups/button3/ZoomMenu/ZoomToFitWidth",
-									 "pixname", pixbuf_xml,
-									 NULL);
-		g_free(pixbuf_xml);
-		gdk_pixbuf_unref(pixbuf);
-		gdk_pixbuf_unref(pixbuf_small);
-	}
 
 	for(i = 0; zoom_level_items[i].path; i++) {
 		bonobo_ui_component_add_listener(control->priv->uic,
@@ -801,7 +773,7 @@ ggv_control_create_ui (GgvControl *control)
 
 		hbox = gtk_hbox_new(FALSE, 2);
 		gtk_widget_show(hbox);
-		zoom_image = gtk_image_new_from_file(GNOMEICONDIR "/ggv/zoom.xpm");
+		zoom_image = gtk_image_new_from_stock(GGV_ZOOM, GTK_ICON_SIZE_LARGE_TOOLBAR);
 		gtk_widget_show(zoom_image);
 		gtk_box_pack_start(GTK_BOX(hbox), zoom_image, FALSE, TRUE, 0);
 		zoom_adj = gtk_adjustment_new(ggv_postscript_view_get_zoom_factor(control->priv->ps_view)*100.0,
@@ -851,9 +823,9 @@ ggv_control_unset_ui_container (GgvControl *control)
 	g_return_if_fail (control != NULL);
 	g_return_if_fail (GGV_IS_CONTROL (control));
 
-	ggv_postscript_view_unset_ui_container (control->priv->ps_view);
-
 	bonobo_ui_component_unset_container (control->priv->uic, NULL);
+
+	ggv_postscript_view_unset_ui_container (control->priv->ps_view);
 }
 
 static void
@@ -874,8 +846,9 @@ ggv_control_activate (BonoboControl *object, gboolean state)
 			ggv_control_set_ui_container (control, ui_container);
 			bonobo_object_release_unref (ui_container, NULL);
 		}
-	} else
+	} else {
 		ggv_control_unset_ui_container (control);
+	}
 
 	if (BONOBO_CONTROL_CLASS (ggv_control_parent_class)->activate)
 		BONOBO_CONTROL_CLASS (ggv_control_parent_class)->activate (object, state);
